[or-cvs] r15830: I think this might actually fix Bug 520. Damn that thing was (torbutton/trunk/src/chrome/content)

mikeperry at seul.org mikeperry at seul.org
Fri Jul 11 08:26:48 UTC 2008


Author: mikeperry
Date: 2008-07-11 04:26:48 -0400 (Fri, 11 Jul 2008)
New Revision: 15830

Modified:
   torbutton/trunk/src/chrome/content/torbutton.js
Log:

I think this might actually fix Bug 520. Damn that thing was
hard to get.



Modified: torbutton/trunk/src/chrome/content/torbutton.js
===================================================================
--- torbutton/trunk/src/chrome/content/torbutton.js	2008-07-11 08:05:33 UTC (rev 15829)
+++ torbutton/trunk/src/chrome/content/torbutton.js	2008-07-11 08:26:48 UTC (rev 15830)
@@ -2384,11 +2384,18 @@
 
         browser.__tb_tor_fetched = !tor_tag;
         browser.docShell.allowPlugins = tor_tag || !kill_plugins;
-        browser.docShell.allowJavascript = js_enabled;
-
-        // We need to do the resize here as well in case the window
-        // was minimized during toggle...
-        torbutton_check_round(browser);
+        if(browser.docShell.allowJavascript != js_enabled) {
+            torbutton_log(3, "Javascript changed to: "+js_enabled);
+            browser.docShell.allowJavascript = js_enabled;
+            torbutton_check_round(browser);
+            // JS was not fully enabled for some page elements. 
+            // Need to reload
+            browser.reload(); 
+        } else {
+            // We need to do the resize here as well in case the window
+            // was minimized during toggle...
+            torbutton_check_round(browser);
+        }
     }
 
     torbutton_log(2, "Tags updated.");



More information about the tor-commits mailing list